function [varargout] = A_Input_Data_RBDO(dia_shaft)
    %% SHAFT
    area_shaft = pi .* (dia_shaft./2).^2;       % area do eixo [m^2]
    I_shaft = (pi .* dia_shaft.^4)./64;         % Momento de inercia do eixo [kg*m^2]

    %% SHAFT MATERIAL: STEEL
    %dens = 7850;                              % Densidade [kg/m^3]
    Po = 0.3;                                   % Coeficiente de Poisson do aco [N/A]

    %% DISC
    dia_disc = 90e-3;                       % diametro disco [m]
    length_disc = 47e-3;                    % comprimento do disco [m]
    mass_disc = 2.3;                        % dens * length_disc * pi * (dia_disc/2)^2;% massa do disco [kg];
    Ip_disc = (1 / 8) * mass_disc * (dia_disc^2);                      % Momento de inercia polar do disco [kg*m^2] formula conforme o livro do Friswell Tabela A1.1 do Apendice 1 
    Id_disc = Ip_disc / 2 + mass_disc * length_disc^2 / 12;            % Momento de inercia diametral do disco [kg*m^2]

    %%% CILINDRICAL BEARING
    h0 = 90e-6;                             % Folga radial do mancal (delta) [m]
    dia_brg = 30e-3;                        % Diametro do mancal [m]
    r_brg = dia_brg/2;                      % Raio do mancal [m]
    area_brg = (pi * dia_brg^2) / 4;        % Area do mancal [m^2]
    I_brg = (pi * dia_brg^4) / 64;          % Momento de inercia da secao transversal do mancal [m^4]
    brg_number = 2;                         % Numero de mancais

    %% Outputs
    varargout{1} = (dia_shaft);
    varargout{2} = (area_shaft);
    varargout{3} = (I_shaft);

    varargout{4} = (Ip_disc);
    varargout{5} = (h0);
    varargout{6} = (r_brg);
    varargout{7} = (area_brg);
    varargout{8} = (I_brg);
    varargout{9} = (brg_number);
    
    varargout{10} = (mass_disc);
    varargout{11} = (Id_disc);
end
