function [varargout] = B_FEM_Geometry_NonCentralDisc_17NODES(area_shaft, area_brg, I_shaft, I_brg, dia_shaft, brg_number)

    %% ELEMENTOS FINITOS PARA 17 NOS
    % PARAMETROS DA MALHA
    Nel = 16;                     % Numero de elementos;
    Nnos = Nel + 1;               % Numero de nos;
    df = 4;                       % Numero de graus de liberdade
    %% DISTRIBUICAO DO EIXO ELEMENTO|NO1|NO2|DISTANCIA[m]
    %% 1 | 1  | 2  | 40e-3
    %% 2 | 2  | 3  | 10.0e-3
    %% 3 | 3  | 4  | 10.0e-3 - NO 3 Mancal A
    %% 4 | 4  | 5  | 33.7e-3
    %% 5 | 5  | 6  | 33.7e-3
    %% 6 | 6  | 7  | 33.7e-3
    %% 7 | 7  | 8  | 33.9e-3 - NO 8 DISCO
    %% 8 | 8  | 9  | 82e-3
    %% 9 | 9  | 10 | 82e-3
    %% 10| 10 | 11 | 82e-3
    %% 11| 11 | 12 | 82e-3
    %% 12| 12 | 13 | 82e-3
    %% 13| 13 | 14 | 82e-3
    %% 14| 14 | 15 | 10.0e-3 - NO 15 Mancal B
    %% 15| 15 | 16 | 10.0e-3
    %% 16| 16 | 17 | 40e-3

    a = 145e-3;                                                     % Distancia entre o mancal 1 (lado esquerdo) ate o centro do disco [m]
    b = 502e-3;                                                     % Distancia entre o mancal 2 (lado direito) ate o centro do disco [m]
    brg_span = a+b;                                                 % Distancia entre os centros dos mancais [m]

    node_mancais = [3, 15];                                         % Indice dos nos dos mancais 3 e 15
    node_disco = 8;                                                 % Indice do disco n� 6
    mancais_ele = [2,3; 14,15];                                     % Elemento dos mancais A e B (para alterar as prop. devido ao diametro)

    dists = [40, 10, 10, 33.7, 33.7, 33.7, 33.9, 82, 82, 82, 82, 82, 82, 10, 10, 40]*10^(-3); % Vetor que contem o comprimento no eixo X de cada elemento [m]

    length_brg = zeros(1, brg_number);
    for j = 1:brg_number
    length_brg(j) = sum(dists((node_mancais(j)-1):node_mancais(j)));
    end
    for i = 1:brg_number
    if i+1 <= brg_number
      if length_brg(i) == length_brg(i+1)
          length_brg = length_brg(i); 
      end
    end
    end

    %length_shaft = sum(dists);
    
    %% Vetores de Geometria do EIXO
    area = zeros(Nel,length(area_shaft));
    mom_ine = zeros(Nel,length(area_shaft)); 
    dia = zeros(Nel,length(area_shaft));

    for ii = 1:length(area_shaft)
        area(:,ii) = area_shaft(ii);                       % Area do eixo
        mom_ine(:,ii) = I_shaft(ii);                       % Mom. de Inercia do eixo
        dia(:, ii) = dia_shaft(ii);                        % Diametro do eixo.
    end


    %% Adicionando a Geometria dos MANCAIS
    area(mancais_ele(1,:),:) = area_brg;          % Area do mancal 1
    area(mancais_ele(2,:),:) = area_brg;          % Area do mancal 2

    mom_ine(mancais_ele(1,:),:) = I_brg;          % Mom. de Inercia do mancal 1
    mom_ine(mancais_ele(2,:),:) = I_brg;          % Mom. de Inercia do mancal 2

    %% Outputs
    varargout{1} = (a);
    varargout{2} = (b);
    varargout{3} = (brg_span);

    varargout{4} = (node_mancais);
    varargout{5} = (node_disco);
    
    varargout{6} = (dists);
    varargout{7} = (Nel);
    varargout{8} = (Nnos);
    varargout{9} = (df);

    varargout{10} = (area);
    varargout{11} = (mom_ine);

    varargout{12} = (length_brg);
end
