  %% Montagem da matriz global de todos os nos e elementos (sem condicao de contorno)
function [varargout] = D_FEM_GlobalMatrix_FlexBrg_alternativa1(ii, ...
                                   c1, c2, c3, c4, c5, c6, ...
                                   g1, g2, g3, g4, ...
                                   a1, a2, a3, a4, ...
                                   Nel, ...
                                   beta, n_omega, k11, k12, k21, k22, d11, d12, d21, d22, ...
                                   node_mancais, node_disco, mass_disc, Id_disc, brg_number, Ip_disc, ind_eq, ...
                                   Kg, Mg, Cg, Gg, Kgk, Cgk, Mgk, Ggk)
for i = 1:Nel
      % According to Kramer 16.31, pg 222
      % Or according to Friswell 5.63, pg 189
      %% Matriz de Massa do elemento
      me_upper = [  c1(i, ii),          0,          0, -c3(i, ii),   c2(i, ii),         0,          0,  c4(i, ii) ;
                            0,  c1(i, ii),  c3(i, ii),          0,           0, c2(i, ii), -c4(i, ii),          0 ;
                            0,          0,  c5(i, ii),          0,           0, c4(i, ii), -c6(i, ii),          0 ;
                            0,          0,          0,  c5(i, ii),  -c4(i, ii),         0,          0, -c6(i, ii) ;
                            0,          0,          0,          0,   c1(i, ii),         0,          0,  c3(i, ii) ;
                            0,          0,          0,          0,           0, c1(i, ii), -c3(i, ii),          0 ;
                            0,          0,          0,          0,           0,         0,  c5(i, ii),          0 ;
                            0,          0,          0,          0,           0,         0,          0,  c5(i, ii)];
      
      Me = me_upper + me_upper' - diag(diag(me_upper));

      %% Matriz Giroscopica do elemento
      ge_upper = [ 0,   g1(i, ii),  g2(i, ii),          0,          0, -g1(i, ii),  g2(i, ii),          0 ;
                   0,           0,          0,  g2(i, ii),  g1(i, ii),          0,          0,  g2(i, ii) ;
                   0,           0,          0,  g4(i, ii),  g2(i, ii),          0,          0,  g3(i, ii) ;
                   0,           0,          0,          0,          0,  g2(i, ii),  g3(i, ii),          0 ;
                   0,           0,          0,          0,          0,  g1(i, ii), -g2(i, ii),          0 ;
                   0,           0,          0,          0,          0,          0,          0, -g2(i, ii) ;
                   0,           0,          0,          0,          0,          0,          0,  g4(i, ii) ;
                   0,           0,          0,          0,          0,          0,          0,          0];
      Ge = ge_upper + ge_upper' - diag(diag(ge_upper));

      %% Matriz de Rigidez do elemento
      ke_upper = [  a1(i, ii),          0,          0, -a2(i, ii), -a1(i, ii),          0,          0, -a2(i, ii) ;
                            0,  a1(i, ii),  a2(i, ii),          0,          0, -a1(i, ii),  a2(i, ii),          0 ;
                            0,          0,  a3(i, ii),          0,          0, -a2(i, ii),  a4(i, ii),          0 ;
                            0,          0,          0,  a3(i, ii),  a2(i, ii),          0,          0,  a4(i, ii) ;
                            0,          0,          0,          0,  a1(i, ii),          0,          0,  a2(i, ii) ;
                            0,          0,          0,          0,          0,  a1(i, ii), -a2(i, ii),          0 ;
                            0,          0,          0,          0,          0,          0,  a3(i, ii),          0 ;
                            0,          0,          0,          0,          0,          0,          0,  a3(i, ii)];
      Ke = ke_upper + ke_upper' - diag(diag(ke_upper));

      %% Matriz de Amortecimento interno do elemento
      Ce = beta * Ke;

      %% Adicionando as matrizes dos elementos na matriz global      
      Kg(ind_eq(i,:),ind_eq(i,:)) = Kg(ind_eq(i,:), ind_eq(i,:)) + Ke;
      Mg(ind_eq(i,:),ind_eq(i,:)) = Mg(ind_eq(i,:), ind_eq(i,:)) + Me;
      Gg(ind_eq(i,:),ind_eq(i,:)) = Gg(ind_eq(i,:), ind_eq(i,:)) + Ge;
      Cg(ind_eq(i,:),ind_eq(i,:)) = Cg(ind_eq(i,:), ind_eq(i,:)) + Ce;

end

%% ADICIONANDO OS COMPONENTES DOS MANCAIS E DO DISCO:
for k = 1:n_omega
  % Forcando copia
  Kgk(:,:,k) = Kg(:,:);
  Cgk(:,:,k) = Cg(:,:);
  Mgk(:,:,k) = Mg(:,:);
  Ggk(:,:,k) = Gg(:,:);

  %% Adicionando os componentes de rigidez e amortecimento dos mancais na matriz global.
  for m = 1:brg_number
      ind_brg = ind_eq(node_mancais(m), 1:4);
      Kgk(ind_brg, ind_brg, k) = Kgk(ind_brg, ind_brg, k) + [k11(m, k), k12(m, k), 0, 0;
                                                             k21(m, k), k22(m, k), 0, 0;
                                                                     0,         0, 0, 0;
                                                                     0,         0, 0, 0];

      Cgk(ind_brg, ind_brg, k) = Cgk(ind_brg, ind_brg, k) + [d11(m, k), d12(m, k), 0, 0;
                                                             d21(m, k), d22(m, k), 0, 0;
                                                                     0,         0, 0, 0;
                                                                     0,         0, 0, 0];
  end

  %% EFEITO DOS DO DISCO NA MATRIZ GLOBAL:
  ind_disc = ind_eq(node_disco, 1:4);

  % Conforme o livro de Friswell (Equacao 3.49) ou Kramer 16.20, pg 219
  Mgk(ind_disc, ind_disc, k) = Mgk(ind_disc, ind_disc, k) + diag([mass_disc, mass_disc, Id_disc, Id_disc]);

  % Conforme o livro de Friswell (Equacao 3.49) ou Kramer 16.20, pg 219
  Ggk(ind_disc, ind_disc, k) = Ggk(ind_disc, ind_disc, k) + [0,  0,        0,       0 ;
                                                              0, 0,        0,       0 ;
                                                              0, 0,        0, Ip_disc ;
                                                              0, 0, -Ip_disc,       0];
end

  %% Output
  varargout{1} = (Kgk);
  varargout{2} = (Cgk);
  varargout{3} = (Mgk);
  varargout{4} = (Ggk);
end

