%% 1 - INITIALIZE UQLAB
clearvars
rng(1,'twister')
uqlab

%% 2 - COMPUTATIONAL MODEL
%% 2.1 - COST FUNCTION - Funo a ser minimizada.
% c(d) : c  a funo custo, e d so as varveis de projeto 
RBDOOpts.Cost.mString = '(pi * X(:,1).^2) ./ 4';

%% 2.2 - LIMIT STATE FUNCTION
%% CONSTRAINT FUNCTION
%% HARD CONSTRAINT / LIMIT STATE FUNCTION: g_k(x)
ModelOpts.mFile = 'Rotor_FlexBrg_WFound_rev2';
myModel = uq_createModel(ModelOpts);

% Assign the model as limit-state for the RBDO problem:
RBDOOpts.LimitState.Model = myModel;

%% 2.3 - SOFT CONSTRAINT: f_j(x): No se aplica pois e
% alguma restricao de parametro de entrada, que seria neste caso restricoes geometricas.

%% 3 - PROBABILISTIC INPUT MODEL
%% 3.1 - DESIGN VARIABLES
% variable to be otimized
RBDOOpts.Input.DesVar(1).Name = 'd';
RBDOOpts.Input.DesVar(1).Type = 'constant';

%% 3.2 - ENVIRONMENTAL VARIABLES
Iopts.Marginals(1).Name = 'E' ;
Iopts.Marginals(1).Type = 'Gaussian';
Iopts.Marginals(1).Moments = [200e9 10e9];

%%
% Create an INPUT object based on the specified marginals:
myInput = uq_createInput(Iopts);

%%
% Associate the INPUT object to the RBDO analysis:
RBDOOpts.Input.EnvVar = myInput ;


%% 4 - OPTIMIZATION SETUP
% DESIGN SPACE: the bounds of the design space are first defined as follows:
RBDOOpts.Optim.Bounds = [0.010; 0.016];

% Optionally, the starting point for the optimization algorithm can also be provided:
RBDOOpts.Optim.StartingPoint = 0.011;

% Define the target failure probability:
RBDOOpts.TargetPf = 0.01;

%% 5 - RELIABILITY-BASED DESIGN OPTIMIZATION (RBDO)
%{
%% 5.1 - RIA - Reliability Index Approach
% RIA is a TWO-LEVEL approach with FORM in the inner loop.
% Use reliability index as constraint instead of the failure probability
% Select the RBDO module and the two-level approach:
RIAOpts = RBDOOpts;
RIAOpts.Type = 'RBDO';
RIAOpts.Method = 'RIA';

RIAOpts.Reliability.FORM.StartingPoint = RBDOOpts.Optim.StartingPoint;
%RIAOpts.Gradient.h = 0.001; % by default: 10e-3

% Run the RBDO analysis:
myRBDO_RIA = uq_createAnalysis(RIAOpts);

% Print out a report of the reults:
uq_print(myRBDO_RIA)

% Display a graphical representation of the results:
uq_display(myRBDO_RIA)    %como so temos 1 variavel ele nao plota esse grafico.
%}
%{
%%  PMA - Performance Measure Approach
% PMA is a two-level approach with an inverse FORM in the inner loop
% and the use of the reliability index as constraint instead of the failure probability 
PMAOpts = RBDOOpts;
PMAOpts.Type = 'RBDO';
PMAOpts.Method = 'PMA';

myRBDO_PMA = uq_createAnalysis(PMAOpts) ;

uq_display(myRBDO_PMA)
uq_print(myRBDO_PMA)
%}

%% SORA - Sequential Pptimization and Reliability Assessment
SORAOpts = RBDOOpts;
SORAOpts.Type = 'RBDO';
SORAOpts.Method = 'SORA';

myRBDO_SORA = uq_createAnalysis(SORAOpts) ;

uq_display(myRBDO_SORA)
uq_print(myRBDO_SORA)
%}
%{
%% SLA - Single Loop Approach
SLAOpts = RBDOOpts;
SLAOpts.Type = 'RBDO';
SLAOpts.Method = 'SLA';

myRBDO_SLA = uq_createAnalysis(SLAOpts) ;

uq_display(myRBDO_SLA)
uq_print(myRBDO_SLA)
%}
%{
%% TWO-LEVEL APPROACH WITH MONTE CARLO SIMULATION
TLOpts = RBDOOpts ;
TLOpts.Type = 'RBDO';
TLOpts.Method = 'two-level';
TLOpts.Reliability.Simulation.MaxSampleSize = 5e4;
TLOpts.Optim.MaxIter = 350;

myRBDO_TL = uq_createAnalysis(TLOpts) ;

uq_display(myRBDO_TL)
uq_print(myRBDO_TL)
%}

%{
%% QMC - QUANTILE MONTE CARLO APPROACH
QMCOpts = RBDOOpts;
QMCOpts.Type = 'RBDO';
QMCOpts.Method = 'QMC';

QMCOpts.Reliability.Simulation.MaxSampleSize = 1e5 ;  % For the surrogate approach this is not used.
QMCOpts.Reliability.Simulation.Sampling = 'MC' ;      % For the surrogate approach this is not used.

% Run the RBDO analysis:
myRBDO_QMC = uq_createAnalysis(QMCOpts);              % For the surrogate approach this is not used.

uq_display(myRBDO_QMC)                                % For the surrogate approach this is not used.
uq_print(myRBDO_QMC)                                  % For the surrogate approach this is not used.
%}
%{
%% Surrogate-Assisted RBDO
RBDOOpts.Type = 'RBDO';
RBDOOpts.Method = 'QMC';            % Quantile MOnte Carlo
%}
%% Specifying a surrogate model
%{
%% Polynomial chaos expansions (PCE)
% Initialize the options for PCE-assisted RBDO:
RBDO_PCEOpts = RBDOOpts;

% Specify PCE as the metamodel type for RBDO:
RBDO_PCEOpts.Metamodel.Type = 'PCE';

% Set the options for the PCE metamodel:
PCEOpts.Degree = 2:10 ;
PCEOpts.ExpDesign.NSamples = 10 ;
PCEOpts.ExpDesign.Sampling = 'LHS' ;

% Specify the options for the construction of the PCE metamodel to the RBDO options:
RBDO_PCEOpts.Metamodel.PCE = PCEOpts;

% Specify the enrichment options for the adaptive experimental design:
RBDO_PCEOpts.Metamodel.Enrichment.Convergence = {'stopSign','stopDf'};
RBDO_PCEOpts.Metamodel.Enrichment.ConvThreshold = 0.001;
RBDO_PCEOpts.Metamodel.Enrichment.MaxAdded = 50;
RBDO_PCEOpts.Metamodel.Enrichment.MOStrategy = 'mean';

% Run the RBDO analysis:
myRBDO_PCE = uq_createAnalysis(RBDO_PCEOpts);

% Print out a report of the results:
uq_print(myRBDO_PCE)

% Display a graphical representation of the results:
uq_display(myRBDO_PCE)
%}
%{
%% Kriging
% Initialize the options for Kriging-assisted RBDO:
RBDO_KrgOpts = RBDOOpts;

% Select Kriging as the metamodel type for RBDO:
RBDO_KrgOpts.Metamodel.Type = 'Kriging';

% Set the options for the Kriging metamodel:
KrgOpts.EstimMethod = 'ML';
KrgOpts.Corr.Family = 'matern-5_2';
KrgOpts.Corr.Isotropic = false;
KrgOpts.Optim.Method = 'HGA';
KrgOpts.ExpDesign.NSamples = 10;

% Specify the options for the construction of the Kriging metamodel"
RBDO_KrgOpts.Metamodel.KRIGING = KrgOpts;

% Specify the enrichment options for the adaptive experimental design:
RBDO_KrgOpts.Metamodel.Enrichment.Convergence = {'stopSign','stopDf'};
RBDO_KrgOpts.Metamodel.Enrichment.ConvThreshold = 0.001;
RBDO_KrgOpts.Metamodel.Enrichment.MaxAdded = 50;
RBDO_KrgOpts.Metamodel.Enrichment.Points = 2;

% Specify SQP as the optimization algorithm:
RBDO_KrgOpts.Optim.Method = 'SQP';

% Run the RBDO analysis:
myRBDO_Krg = uq_createAnalysis(RBDO_KrgOpts);

% Print out a report of the results:
uq_print(myRBDO_Krg)

% Display a graphical representation of the results:
uq_display(myRBDO_Krg)
%}

%{
%% Metamodelling approach: SRV - Support Vector Machines for Regression
% Initialize the options for SVR-assisted RBDO:
RBDO_SVROpts = RBDOOpts;

% Include the INPUT and MODEL objects to the SVR metamodel configuration:
% RBDO_SVROpts.Input = myInput;
% RBDO_SVROpts.FullModel = myModel;

% Specify the metamodel type for RBDO:
RBDO_SVROpts.Metamodel.Type = 'SVR';

% Set the options for the SVR metamodel:
SVROpts.Loss = 'l2-eps';
SVROpts.Kernel.Family = 'matern-5_2';
SVROpts.Kernel.Isotropic = false;
SVROpts.Optim.Method = 'HCMAES';
SVROpts.ExpDesign.NSamples = 50;

% Specify the options for the construction of the SVR metamodel:
RBDO_SVROpts.Metamodel.SVR = SVROpts;

% Specify IP as the optimization algorithm:
RBDO_SVROpts.Optim.Method = 'IP';
  
% Run the RBDO analysis:
myRBDO_SVR = uq_createAnalysis(RBDO_SVROpts);

% Print out a report of the results:
uq_print(myRBDO_SVR)

% Display a graphical representation of the results:
uq_display(myRBDO_SVR)
%}


